@@ -89,7 +89,7 @@ SeriesHandler::GetVoxelSize()
 {
   std::vector<double> voxel_size(3, 0);
   std::string s;
-  if(Find("PixelSpacing", s)) {
+  if (Find("PixelSpacing", s)) {
     voxel_size[0] = stof(s, 0);
     voxel_size[1] = stof(s, 1);
   }
@@ -141,7 +141,7 @@ SeriesHandler::GetFilenames() const
 bool
 SeriesHandler::IsBigEndian() const
 {
-  if (mFileMap.empty()) return 0;
+  if (mFileMap.empty()) { return false; }
   DicomFile dicomFile((*mFileMap.begin()).first.c_str());
   return dicomFile.IsBigEndian();
 }
@@ -180,7 +180,7 @@ int
 SeriesHandler::GetRescaleSlopeAndIntercept(const VolId& id, double& slope, double& intercept) const
 {
   std::string filename;
-  if (!GetFirstFilename(id, filename)) return 0;
+  if (!GetFirstFilename(id, filename)) { return 0; }
   DicomFile dicomFile(filename.c_str());
   return GetRescaleSlopeAndIntercept(dicomFile, slope, intercept);
 }
@@ -193,8 +193,8 @@ SeriesHandler::GetRescaleSlopeAndIntercept(const VolId& id, double& slope, doubl
 int
 SeriesHandler::GetRescaleSlopeAndIntercept(DicomFile& dfile, double& slope, double& intercept, int frame) const
 {
-  if (!dfile.Find("RescaleSlope", slope)) slope = 1;
-  if (!dfile.Find("RescaleIntercept", intercept))  intercept = 0;
+  if (!dfile.Find("RescaleSlope", slope)) { slope = 1; }
+  if (!dfile.Find("RescaleIntercept", intercept)) { intercept = 0; }
   return 1;
 }
 
@@ -214,7 +214,7 @@ SeriesHandler::GetVolumeInterval() const
   std::map<VolId, std::vector<double> > vtmap;
   for (double time = 0; it != it_end; ++it) { 
     DicomFile file(it->first.c_str());
-    file.Find(DT_ACQUISITIONTIME, time);
+    file.Find("AcquisitionTime", time);
     vtmap[it->second.front()].push_back(time);
     time = 0;  // Do we trust file.Find to overwrite time?
   }
@@ -265,9 +265,9 @@ SeriesHandler::CheckIntervalSanity(std::vector<double>& vol_times, double retval
 {
   double average = GetMeanVolumeInterval(vol_times);
   std::string str_tr;
-  Find(DT_REPETITIONTIME, str_tr);
+  Find("RepetitionTime", str_tr);
   int tr;
-  if ( ! (std::istringstream(str_tr) >> tr) ) {
+  if (!(std::istringstream(str_tr) >> tr)) {
     tr = 0;
   }
   // Convert tr to seconds.
@@ -299,22 +299,22 @@ SeriesHandler::CheckIntervalSanity(std::vector<double>& vol_times, double retval
 double
 SeriesHandler::GetMeanVolumeInterval(std::vector<double>& vol_times) const
 {
+  double average = 0;
   std::vector<double>::iterator dit = vol_times.begin();
   std::vector<double>::iterator dit_end = vol_times.end();
   std::vector<double> vol_diffs;
-  for (++dit; dit < dit_end; ++dit) {
-    vol_diffs.push_back(*dit - *(dit - 1));
+  if (dit < dit_end) {
+    for (++dit; dit < dit_end; ++dit) {
+      vol_diffs.push_back(*dit - *(dit - 1));
+    }
+    std::vector<double>::iterator diff = vol_diffs.begin();
+    std::vector<double>::iterator diff_end = vol_diffs.end();
+    double sum = 0;
+    for (; diff < diff_end; ++diff) {
+      sum += *diff;
+    }
+    average = sum / vol_diffs.size();
   }
-  std::vector<double>::iterator diff = vol_diffs.begin();
-  std::vector<double>::iterator diff_end = vol_diffs.end();
-  double sum = 0;
-  for (; diff < diff_end; ++diff) {
-    sum += *diff;
-    //std::cout << *diff << std::endl;
-  }
-  double average = sum / vol_diffs.size();
-  //std::cout << average << " = " << sum << " / " << vol_diffs.size() <<std::endl;
-
   return average;
 }
 
@@ -337,7 +337,7 @@ int
 SeriesHandler::GetColumns()
 {
   int columns;
-  Find(DT_IMAGECOLUMNS, columns);
+  Find("ImageColumns", columns);
   return columns;
 }
 
@@ -350,7 +350,7 @@ int
 SeriesHandler::GetRows()
 {
   int rows;
-  Find(DT_IMAGEROWS, rows);
+  Find("ImageRows", rows);
   return rows;
 }
 
@@ -363,7 +363,7 @@ int
 SeriesHandler::GetFrames() const
 {
   int frames = 0;
-  Find(DT_NUMBEROFFRAMES, frames);
+  Find("NumberOfFrames", frames);
   return frames;
 }
 
@@ -377,12 +377,12 @@ SeriesHandler::GetFrames() const
 int
 SeriesHandler::AddFile(const char* filename)
 {
-  if (mFileMap.count(filename)) return 0;
+  if (mFileMap.count(filename)) { return 0; }
 
   DicomFile dicom_file(filename);
 
   std::string series_uid;
-  dicom_file.Find(DT_SERIESINSTANCEUID, series_uid);
+  dicom_file.Find("SeriesInstanceUid", series_uid);
 
   // Fix problems with termination
   std::string temp(series_uid.c_str());
@@ -392,7 +392,7 @@ SeriesHandler::AddFile(const char* filename)
   assert(mSeriesUid == series_uid);
 
   std::string uid;
-  dicom_file.Find(DT_SOPINSTANCE, uid);
+  dicom_file.Find("SopInstance", uid);
   if (mInstanceUids.count(uid) == 0 ) {
     mInstanceUids.insert(uid);
     VolListType info = ReadVolIds(dicom_file);
@@ -400,16 +400,16 @@ SeriesHandler::AddFile(const char* filename)
   }
   
   if (seriesInfo.SeriesDate == "") {
-    Find(DT_PATIENTID, seriesInfo.subject_id);
-    Find(DT_PATIENTNAME, seriesInfo.subject_name);
-    Find(DT_STUDYID, seriesInfo.study_number);
-    Find(DT_STUDYDESCRIPTION, seriesInfo.study_description);
+    Find("PatientId", seriesInfo.subject_id);
+    Find("PatientName", seriesInfo.subject_name);
+    Find("StudyId", seriesInfo.study_number);
+    Find("StudyDescription", seriesInfo.study_description);
     int series_number;
-    Find(DT_SERIESNUMBER, series_number);
+    Find("SeriesNumber", series_number);
     seriesInfo.series_number = itos(series_number, 3);
-    Find(DT_STUDYDATE, seriesInfo.StudyDate);
-    Find(DT_SERIESDATE, seriesInfo.SeriesDate);
-    Find(DT_SERIESDESCRIPTION, seriesInfo.series_description);
+    Find("StudyDate", seriesInfo.StudyDate);
+    Find("SeriesDate", seriesInfo.SeriesDate);
+    Find("SeriesDescription", seriesInfo.series_description);
   }
 
   return 1;
@@ -426,16 +426,17 @@ SeriesHandler::GetStringInfo()
   std::vector<std::string> v;
 
   v.push_back(std::string("Series UID: ") + GetSeriesUid());
-  v.push_back(std::string("Study date: ") + Find(DT_STUDYDATE));
-  v.push_back(std::string("Study time: ") + Find(DT_STUDYTIME));
-  v.push_back(std::string("Series date: ") + Find(DT_SERIESDATE));
-  v.push_back(std::string("Series time: ") + Find(DT_SERIESTIME));
-  v.push_back(std::string("Subject: ") + Find(DT_PATIENTNAME));
-  v.push_back(std::string("Series description: ") + Find(DT_SERIESDESCRIPTION));
+  v.push_back(std::string("Study date: ") + Find("StudyDate"));
+  v.push_back(std::string("Study time: ") + Find("StudyTime"));
+  v.push_back(std::string("Series date: ") + Find("SeriesDate"));
+  v.push_back(std::string("Series time: ") + Find("SeriesTime"));
+  v.push_back(std::string("Subject: ") + Find("PatientName"));
+  v.push_back(std::string("Subject birth date: ") + Find("PatientBirthDate"));
+  v.push_back(std::string("Series description: ") + Find("SeriesDescription"));
   v.push_back(std::string("Manufacturer: ") + Find("Manufacturer"));
   v.push_back(std::string("Model name: ") + Find("ModelName"));
-  v.push_back(std::string("Study id: ") + Find(DT_STUDYID));
-  v.push_back(std::string("Series number: ") + Find(DT_SERIESNUMBER));
+  v.push_back(std::string("Study id: ") + Find("StudyId"));
+  v.push_back(std::string("Series number: ") + Find("SeriesNumber"));
   v.push_back(std::string("Repetition time (ms): ") + Find("RepetitionTime"));
 
   GetEchoTimes();
@@ -469,12 +470,15 @@ SeriesHandler::GetStringInfo()
   }
 
   if (!orientations.empty()) {
-    if (orientations.front().at(1) > orientations.front().at(0)) // sagital slices
-    v.push_back(std::string("Orientation: sag"));
-    else if (orientations.front().at(4) > fabs(orientations.front().at(5))) // transverse slices
-    v.push_back(std::string("Orientation: tra"));
-    else // coronal slices
-    v.push_back(std::string("Orientation: cor"));
+    if (orientations.front().at(1) > orientations.front().at(0)) { // sagital slices
+      v.push_back(std::string("Orientation: sag"));
+    }
+    else if (orientations.front().at(4) > fabs(orientations.front().at(5))) { // transverse slices
+      v.push_back(std::string("Orientation: tra"));
+    }
+    else { // coronal slices
+      v.push_back(std::string("Orientation: cor"));
+    }
   }
 
   return v;
@@ -518,20 +522,14 @@ SeriesHandler::ReadVolIds(DicomFile& file)
   // Note also, there is not a good way to guarantee unique volume
   // identifiers, leading to inappropriate overwriting.
   int nframes;
-  if (!file.Find("NumberOfFrames", nframes)) nframes = 1;
+  if (!file.Find("NumberOfFrames", nframes)) { nframes = 1; }
 
   wxUint32 fip;
   wxUint16 fiphi, fiplo;
-  file.Find(DT_FRAMEINCREMENTPOINTER, fip);
+  file.Find("FrameIncrementPointer", fip);
   fiphi = ( fip & 0xFFFF0000 ) >> 16;
   fiplo = ( fip & 0x0000FFFF );
   std::string fip_str;
-  /**
-  if (file.Find(DicomTag(fiphi, fiplo), fip_str)) {
-    std::cout << "stuff at: " << DicomTag(fiphi, fiplo) << fip_str << "---" << std::endl;
-  }
-  **/
-  
   VolListType v;
 
   for (int frameno = 0; frameno < nframes; ++frameno) {
@@ -546,23 +544,23 @@ SeriesHandler::ReadVolIds(DicomFile& file)
     info.ids.push_back(ss.str());
     
     std::string str;
-    file.Find(DT_NUMBEROFTEMPORALPOSITIONS, str);
+    file.Find("NumberOfTemporalPositions", str);
     int ndigits = str.size();
     
     str.clear();
     int tpid = 0;
-    file.Find(DT_TEMPORALPOSITIONID, tpid);
+    file.Find("TemporalPositionId", tpid);
     str = itos(tpid, ndigits);
     info.ids.push_back(str);
 
     str.clear();
     int echonumber = 0;
-    file.Find(DT_ECHONUMBER, echonumber);
+    file.Find("EchoNumber", echonumber);
     str = itos(echonumber, 2);
     info.ids.push_back(str);
     
     std::string ImageType;
-    file.Find(DT_IMAGETYPE, ImageType);
+    file.Find("ImageType", ImageType);
 
     if (ImageType.find("DERIVED") != std::string::npos) {
       info.ids.push_back("D");
@@ -591,7 +589,7 @@ SeriesHandler::ReadVolIds(DicomFile& file)
     rotation.resize(9, 0);
 
     std::string iop;
-    if (!file.Find(DT_IMAGEORIENTATIONPATIENT, iop)) {
+    if (!file.Find("ImageOrientationPatient", iop)) {
       iop = "1\\0\\0\\0\\1\\0";
     }
     
@@ -697,7 +695,7 @@ SeriesHandler::GetFirstFilename(const VolId& id, std::string& str) const
   VolListType::const_iterator vit;
   for (it = mFileMap.begin(); it != mFileMap.end(); it++) {
     for (vit = it->second.begin(); vit != it->second.end(); vit++) {
-      if(*vit == id) {
+      if (*vit == id) {
         str = it->first;
         return true;
       }
